[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/MauricioSalazare/spheral/master?urlpath=lab/tree/examples)
[![MIT License](https://img.shields.io/badge/License-MIT-yellow)](https://github.com/MauricioSalazare/spheral/blob/master/LICENSE)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/multicopula)](https://pypi.python.org/pypi/spheral/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/multicopula)](https://pypi.python.org/pypi/spheral/)
[![GitHub code size in bytes](https://img.shields.io/github/languages/code-size/MauricioSalazare/spheral)]((https://github.com/MauricioSalazare/spheral))
[![PyPI - Version](https://img.shields.io/pypi/v/spheral)](https://pypi.python.org/pypi/spheral/)

# Spheral
## What is Spheral?
It is a principal component analysis (PCA) dimensionality reduction technique that projects the data into a Sphere-like
structure.

## How to install
The package can be installed via pip using:

```shell
    pip install spheral
```